# WRITES OUT PDB files for all frames
# INPUT : -args psf dcd prefix
#       : psf = psf file for trajectory
#       : dcd = dcd file for trajectory
#       : prefix = prefix for output pdb files. i.e. <prefix>00001.pdb, <prefix>00002.pdb, etc.
set psf    [lindex $argv 0]
set dcd    [lindex $argv 1]
set prefix [lindex $argv 2]

set psfbase [lindex [split $psf "."] 0 ]
set dcdbase [lindex [split $dcd "."] 0 ]

mol new $psf
set dna [atomselect top nucleic]
set segs [lsort -unique [$dna get segid]]
if {[llength $segs] != 2} {
  puts "WARNING, number of DNA strands present is not exactly two, TCL script will not work"
  puts "ABORTING"
  exit
}
set strands {}
foreach seg $segs {
  set temp [atomselect top "nucleic and segid $seg"]
  lappend strands $temp
}
set dna1 [lindex $strands 0]
set dna2 [lindex $strands 1]

set num 0

set dcdlist [list $dcd]
foreach dcdFile $dcdlist {
 mol addfile $dcdFile waitfor all
 set nf [molinfo top get numframes]
 for {set f 0} {$f < $nf} {incr f} {
  animate goto $f
  $dna frame $f
  $dna1 frame $f
  $dna2 frame $f
  set periodcell [molinfo top get {a b c}]
  set A [measure center $dna1 weight mass]
  set B [measure center $dna2 weight mass]
  set diff [vecsub $A $B]
  set mv [list 0 0 0]
  foreach dir [list 0 1 2] {
    if {[lindex $diff $dir] > [lindex $periodcell $dir]/2} {
      lset mv $dir [lindex $periodcell $dir]
    }
    if {[lindex $diff $dir] < -[lindex $periodcell $dir]/2} {
      lset mv $dir -[lindex $periodcell $dir]
    }
  }
  $dna2 moveby $mv

  set numstring [format %5.5d $num]
  incr num
  set A [measure center $dna1 weight mass]
  set B [measure center $dna2 weight mass]
  if {[veclength [vecsub $A $B]]>10} {
    puts "ERROR!!!!!!!!! DNA strands centers of mass separated by greater than 10 angstroms!!"
    exit
  }

  $dna writepdb "$prefix$numstring.pdb"
 }
 animate delete all
}
exit
